@@ -3,11 +3,11 @@ package Math::ColorRGBA;
 use strict;
 use warnings;
 
-our $VERSION = '0.222';
+our $VERSION = '0.224';
 
 use base 'Math::Color';
 
-use constant DefaultValue => [ 0, 0, 0, 0 ];
+use constant getDefaultValue => [ 0, 0, 0, 0 ];
 
 =head1 NAME
 
@@ -32,7 +32,7 @@ L<Math::Color>, L<Math::ColorRGBA>, L<Math::Image>, L<Math::Vec2>, L<Math::Vec3>
 
 =head1 DESCRIPTION
 
-=head2 DefaultValue
+=head2 Default value
 
 	0 0 0 0
 
